@@ -15,11 +15,11 @@ our @EXPORT = qw'symbols_list
                  industry_list
                 ' ;
 
-our $VERSION = '3.00';
+our $VERSION = '3.01';
 
 our $long;
 
-my %inds ;
+our %inds ;
 
 sub _carp(@) { carp "@_\n" ; ()}
 
@@ -80,8 +80,6 @@ sub _gimi($$;@) {
     }
     elsif ($prs eq 'ind' and $long) {
         my @ret ;
-                   # http\://biz\.yahoo\.com/ic/\d+/\d+\.html\"\>([^\<]+).*?
-                   # http\://finance\.yahoo\.com/q\?s\=([\w\.]+)
         while ( m{ a \s+
                    href\=\"/quote/(\w+)\?p\=\w+\" \s+
                    title\=\"([^\"]+)\"
@@ -94,13 +92,12 @@ sub _gimi($$;@) {
             href\=\"/quote/(\w+)\?p\=\w+\" \s+
             title\=\"[^\"]+\"
             }xgs
-          # m{http\://finance\.yahoo\.com/q\?s\=([\w\.]+)\s*\"}g
     }
     elsif ($prs eq 'inds') {
 
         while (m{href\=\"/industry/([^\"]+)\" title=\"([^\"]+)\"}g) {
             my ($d, $n) = ($1, $2) ;
-            $inds{ _http2name $n } = $d ;
+            $inds{ _http2name $n } = $d if $d =~ /\w/ and $n =~ /\w/;
         }
         return keys %inds;
     }
@@ -132,7 +129,6 @@ sub industry_list($) {
     #                 # ?? TODO ??
     #                 # support Private/Foreign ? what for?
     _gimi ind => "http://finance.yahoo.com/industry/$n"
-      # "http://biz.yahoo.com/ic/${n}_cl_${p}.html"
 }
 
 1;
